Index: uspace/lib/c/arch/ppc32/src/entry.S
===================================================================
--- uspace/lib/c/arch/ppc32/src/entry.S	(revision ae7d03c05f24b857bbbdbcf3dafbf8ecc6c286ab)
+++ uspace/lib/c/arch/ppc32/src/entry.S	(revision 713ba400ab6e8280ec0acb689e8a197838f7c5b7)
@@ -29,5 +29,5 @@
 #include <abi/asmtool.h>
 
-.section .init, "ax"
+.text
 
 .org 0
@@ -45,6 +45,6 @@
 	stwu %r1, -16(%r1)
 
 	# Pass the PCB pointer to __libc_main() as the first argument.
 	# The first argument is passed in r3.
 	mr %r3, %r6
-	bl __libc_main
+	bl __c_start
@@ -45,6 +45,6 @@
 	stwu %r1, -16(%r1)
 
-	# Pass the PCB pointer to __libc_main() as the first argument.
+	# Pass the PCB pointer to __c_start() as the first argument.
 	# The first argument is passed in r3.
 	mr %r3, %r6
